@@ -80,7 +80,13 @@ class DatasetQuery(Generic[E]):
                 start = slices[1]
                 end = slices[0]
                 subsets[m.group("sname")] = (start, end)
-
+        else:
+            subsets: Dict[str, Tuple[RawSlice, RawSlice]] = {
+                "": (
+                    {"value": 0, "is_percentage": True, "absolute_value": 0},
+                    {"value": 1, "is_percentage": True, "absolute_value": 1},
+                )
+            }
         return DatasetQuery(dataset, subsets, shuffle, seed)
 
     def select(self, array: List[E]) -> DatasetDict[List[E]]:
@@ -93,7 +99,10 @@ class DatasetQuery(Generic[E]):
                 end["absolute_value"] = int(end["value"] * n_exs)
 
             total_percentage = sum(
-                [end["value"] - start["value"] for start, end in self.subsets.values()]
+                [
+                    (end["value"] - start["value"]) * 100
+                    for start, end in self.subsets.values()
+                ]
             )
             n_selected = sum(
                 [
@@ -137,9 +146,15 @@ class DatasetQuery(Generic[E]):
         filters = []
         for subset in subsets:
             start, end = self.subsets[subset]
-            sper = "%" if start["is_percentage"] else ""
-            eper = "%" if end["is_percentage"] else ""
-            filters.append(f"{subset}[{start['value']}{sper}:{end['value']}{eper}]")
+            if start["is_percentage"]:
+                start = f"{int(start['value'] * 100)}%"
+            else:
+                start = start["value"]
+            if end["is_percentage"]:
+                end = f"{int(end['value'] * 100)}%"
+            else:
+                end = end["value"]
+            filters.append(f"{subset}[{start}:{end}]")
 
         filter = "+".join(filters)
         if len(subsets) > 1 or "" not in subsets:
